@@ -1,7 +1,4 @@
-use crate::command::bump::{
-    ensure_tag_is_greater_than_previous, tag_or_fallback_to_zero, HookRunOptions,
-    PackageBumpOptions,
-};
+use crate::command::bump::{HookRunOptions, PackageBumpOptions};
 use crate::conventional::changelog::template::PackageContext;
 use crate::conventional::changelog::ReleaseType;
 use crate::git::tag::Tag;
@@ -10,35 +7,25 @@ use crate::{CocoGitto, SETTINGS};
 use anyhow::Result;
 use colored::*;
 use log::info;
-use semver::{BuildMetadata, Prerelease};
 use tera::Tera;
 
 impl CocoGitto {
     pub fn create_package_version(&mut self, opts: PackageBumpOptions) -> Result<()> {
         self.pre_bump_checks(opts.skip_untracked)?;
 
-        let current_tag = self.repository.get_latest_package_tag(opts.package_name);
-        let current_tag = tag_or_fallback_to_zero(current_tag)?;
-        let mut next_version = current_tag.bump(opts.increment, &self.repository)?;
-        if current_tag == next_version {
-            print!("No conventional commits found for {} that required a bump. Changelog will be updated on the next bump.\nPre-Hooks and Post-Hooks have been skipped.\n",
-                   opts.package_name
-            );
+        let bump_res = opts.common().get_new_version(
+            &self.repository,
+            Some(opts.package_name),
+            false,
+            None,
+        )?;
+        if bump_res.no_change() {
+            print!("No conventional commits found for {} that required a bump. Changelog will be updated on the next bump.\nPre-Hooks and Post-Hooks have been skipped.\n", opts.package_name);
             return Ok(());
         }
 
-        ensure_tag_is_greater_than_previous(&current_tag, &next_version)?;
-
-        if let Some(pre_release) = opts.pre_release {
-            next_version.version.pre = Prerelease::new(pre_release)?;
-        }
-
-        if let Some(build) = opts.build {
-            next_version.version.build = BuildMetadata::new(build)?;
-        }
-
         let tag = Tag::create(
-            next_version.version.clone(),
+            bump_res.next.version.clone(),
             Some(opts.package_name.to_string()),
         );
 
@@ -48,7 +35,7 @@ impl CocoGitto {
         }
 
         if !SETTINGS.disable_changelog {
-            let pattern = self.get_bump_revspec(&current_tag);
+            let pattern = self.get_bump_revspec(&bump_res.current);
             let changelog = self.get_package_changelog_with_target_version(
                 &pattern,
                 tag.clone(),
@@ -72,7 +59,7 @@ impl CocoGitto {
             .ok();
 
         let next_version = HookVersion::new(Tag::create(
-            next_version.version,
+            bump_res.next.version,
             Some(opts.package_name.to_string()),
         ));
 
@@ -107,7 +94,7 @@ impl CocoGitto {
 
         if let Some(msg_tmpl) = opts.annotated {
             let mut context = tera::Context::new();
-            context.insert("latest", &current_tag.version.to_string());
+            context.insert("latest", &bump_res.current.version.to_string());
             context.insert("version", &tag.version.to_string());
             let msg = Tera::one_off(&msg_tmpl, &context, false)?;
             self.repository
