@@ -33,6 +33,9 @@ pub struct CommitConfig {
     /// Allow for this commit type to bump the patch version.
     #[serde(default)]
     pub bump_patch: Option<bool>,
+    /// Specify a sort order attribute for this commit type.
+    #[serde(default)]
+    pub order: Option<u32>,
 }
 
 impl CommitConfig {
@@ -42,6 +45,7 @@ impl CommitConfig {
             omit_from_changelog: Some(false),
             bump_minor: Some(false),
             bump_patch: Some(false),
+            order: Some(0),
         }
     }
 
@@ -55,6 +59,7 @@ impl CommitConfig {
             omit_from_changelog: other.omit_from_changelog.or(self.omit_from_changelog),
             bump_minor: other.bump_minor.or(self.bump_minor),
             bump_patch: other.bump_patch.or(self.bump_patch),
+            order: other.order.or(self.order),
         }
     }
 
@@ -68,6 +73,11 @@ impl CommitConfig {
         self
     }
 
+    pub(crate) fn with_order(mut self, order: u32) -> Self {
+        self.order = Some(order);
+        self
+    }
+
     pub(crate) fn omit_from_changelog(&self) -> bool {
         self.omit_from_changelog.unwrap_or_default()
     }
@@ -161,7 +171,7 @@ impl Commit {
     pub(crate) fn should_omit(&self) -> bool {
         COMMITS_METADATA
             .get(&self.conventional.commit_type)
-            .is_some_and(|config| config.omit_from_changelog())
+            .is_some_and(|config| config.omit_from_changelog() && !self.is_major_bump())
     }
 
     pub(crate) fn is_major_bump(&self) -> bool {
@@ -274,7 +284,7 @@ impl fmt::Display for Commit {
 
 impl PartialOrd for Commit {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        Some(self.conventional.scope.cmp(&other.conventional.scope))
+        Some(self.cmp(other))
     }
 }
 
