@@ -1,5 +1,8 @@
-use std::fmt::{Debug, Formatter};
 use std::path::Path;
+use std::{
+    fmt::{Debug, Formatter},
+    path::PathBuf,
+};
 
 use crate::git::error::Git2Error;
 use git2::{
@@ -9,11 +12,16 @@ use git2::{
 pub(crate) struct Repository(pub(crate) Git2Repository);
 
 impl Repository {
-    pub(crate) fn signin_key(&self) -> Result<String, Git2Error> {
+    pub(crate) fn signing_key(&self) -> Result<String, Git2Error> {
         let config = self.0.config()?;
         config.get_string("user.signingKey").map_err(Into::into)
     }
 
+    pub(crate) fn signing_key_path(&self) -> Result<PathBuf, Git2Error> {
+        let config = self.0.config()?;
+        config.get_path("user.signingKey").map_err(Into::into)
+    }
+
     pub(crate) fn gpg_sign(&self) -> bool {
         let config = self.0.config().expect("failed to retrieve gitconfig");
         config.get_bool("commit.gpgSign").unwrap_or(false)
@@ -93,7 +101,7 @@ impl Repository {
         self.get_head_commit().map(|commit| commit.id())
     }
 
-    pub(crate) fn get_head_commit(&self) -> Result<Git2Commit, Git2Error> {
+    pub(crate) fn get_head_commit(&self) -> Result<Git2Commit<'_>, Git2Error> {
         let head_ref = self.0.head();
         match head_ref {
             Ok(head) => head.peel_to_commit().map_err(Git2Error::PeelToCommitError),
@@ -128,7 +136,7 @@ impl Repository {
     pub(crate) fn tree_to_treeish(
         &self,
         arg: Option<&String>,
-    ) -> Result<Option<Object>, git2::Error> {
+    ) -> Result<Option<Object<'_>>, git2::Error> {
         let arg = match arg {
             Some(s) => s,
             None => return Ok(None),
@@ -275,4 +283,24 @@ mod test {
         assert_that!(shorthand).is_equal_to(Some("master".to_string()));
         Ok(())
     }
+
+    #[sealed_test]
+    fn signing_key_path_resolves_tilde() -> Result<()> {
+        // Arrange
+        let repo = git_init_no_gpg()?;
+
+        // update path to key
+        run_cmd!(
+            git config --local user.signingkey ~/.ssh/key.pub;
+        )?;
+
+        let path_to_signing_key = repo.signing_key_path().unwrap();
+
+        let home_env_var = if cfg!(windows) { "USERPROFILE" } else { "HOME" };
+        let actual_home = std::env::var(home_env_var).unwrap();
+
+        assert!(path_to_signing_key.starts_with(actual_home));
+
+        Ok(())
+    }
 }
