@@ -13,8 +13,8 @@ impl Repository {
         &self,
         pattern: &str,
         package: &str,
-    ) -> Result<CommitIter, Git2Error> {
-        let mut commit_range = self.revwalk(pattern)?;
+    ) -> Result<CommitIter<'_>, Git2Error> {
+        let mut commit_range = self.revwalk_pkg(pattern, Some(package))?;
         let mut commits = vec![];
         let package = SETTINGS.packages.get(package).expect("package exists");
         let package_path_filter = PackagePathFilter::from_package(package);
@@ -62,7 +62,7 @@ impl Repository {
     pub fn get_commit_range_for_monorepo_global(
         &self,
         pattern: &str,
-    ) -> Result<CommitIter, Git2Error> {
+    ) -> Result<CommitIter<'_>, Git2Error> {
         let mut commit_range = self.revwalk(pattern)?;
         let mut commits = vec![];
         let package_paths: Vec<_> = SETTINGS
@@ -71,7 +71,7 @@ impl Repository {
             .map(|package| &package.path)
             .collect();
 
-        for (oid_of, commit) in commit_range.into_iter().rev() {
+        for (oid_of, commit) in commit_range.into_iter() {
             let parent = commit.parent(0);
 
             // First commit is always included in monorepo global tag
@@ -113,8 +113,24 @@ impl Repository {
     }
 
     /// Return a commit range from a [`RevspecPattern2`]
-    pub fn revwalk(&self, spec: &str) -> Result<CommitIter, Git2Error> {
+    pub fn revwalk(&self, spec: &str) -> Result<CommitIter<'_>, Git2Error> {
+        self.revwalk_pkg(spec, None)
+    }
+
+    pub fn revwalk_pkg(
+        &self,
+        spec: &str,
+        package: Option<&str>,
+    ) -> Result<CommitIter<'_>, Git2Error> {
         let spec = self.revspec_from_str(spec)?;
+
+        if spec.from() == spec.to() {
+            let oid = *spec.from();
+            let oid_of = self.resolve_oid_of(&oid.to_string())?;
+            let commit = self.0.find_commit(oid)?;
+            return Ok(CommitIter::single(oid_of, commit));
+        }
+
         let mut revwalk = self.0.revwalk()?;
         revwalk.push_range(&spec.to_string())?;
 
@@ -123,13 +139,13 @@ impl Repository {
         for oid in revwalk {
             let oid = oid?;
             // TODO: can we avoid allocating strings here ?
-            let oid_of = self.resolve_oid_of(&oid.to_string())?;
+            let oid_of = self.resolve_oid_of_package(&oid.to_string(), package)?;
             let commit = self.0.find_commit(oid)?;
             commits.push((oid_of, commit));
         }
 
         // TODO: can we avoid allocating strings here ?
-        let first_oid = self.resolve_oid_of(&spec.from().to_string())?;
+        let first_oid = self.resolve_oid_of_package(&spec.from().to_string(), package)?;
         let include_start = match &first_oid {
             OidOf::Head(_) | OidOf::FirstCommit(_) => true,
             OidOf::Tag(_) | OidOf::Other(_) => false,
@@ -161,7 +177,7 @@ mod test {
     use crate::git::repository::Repository;
     use crate::git::tag::{Tag, TagLookUpOptions};
     use crate::settings::{MonoRepoPackage, Settings};
-    use crate::test_helpers::{commit, git_init_no_gpg, git_tag};
+    use crate::test_helpers::{commit, git_init_no_gpg, git_tag, mkdir};
 
     const COCOGITTO_REPOSITORY: &str = env!("CARGO_MANIFEST_DIR");
 
@@ -320,11 +336,12 @@ mod test {
 
         let settings = toml::to_string(&settings)?;
 
+        mkdir(&["one"])?;
+
         run_cmd!(
             echo $settings > cog.toml;
             git add .;
             git commit -m "chore: First commit";
-            mkdir one;
             echo changes > one/file;
             git add .;
             git commit -m "feat: package one";
@@ -462,9 +479,10 @@ mod test {
 
         let settings = toml::to_string(&settings)?;
 
+        mkdir(&["shared", "one/ignored"])?;
+
         run_cmd!(
             echo $settings > cog.toml;
-            mkdir -p shared one/ignored;
             git add .;
             git commit -m "chore: First commit";
         )?;
@@ -496,9 +514,9 @@ mod test {
         // Arrange
         let repo = Repository::open(COCOGITTO_REPOSITORY)?;
         let v1_0_0 = Oid::from_str("549070fa99986b059cbaa9457b6b6f065bbec46b")?;
-        let _v1_0_0 = OidOf::Tag(Tag::from_str("1.0.0", Some(v1_0_0), None)?);
+        let _v1_0_0 = OidOf::Tag(Tag::from_str("1.0.0", Some(v1_0_0))?);
         let v3_0_0 = Oid::from_str("c6508e243e2816e2d2f58828ee0c6721502958dd")?;
-        let v3_0_0 = OidOf::Tag(Tag::from_str("3.0.0", Some(v3_0_0), None)?);
+        let v3_0_0 = OidOf::Tag(Tag::from_str("3.0.0", Some(v3_0_0))?);
 
         // Act
         let range = repo.revwalk("1.0.0..3.0.0")?;
@@ -527,7 +545,7 @@ mod test {
         };
 
         let v1_0_0 = Oid::from_str("549070fa99986b059cbaa9457b6b6f065bbec46b")?;
-        let _v1_0_0 = OidOf::Tag(Tag::from_str("1.0.0", Some(v1_0_0), None)?);
+        let _v1_0_0 = OidOf::Tag(Tag::from_str("1.0.0", Some(v1_0_0))?);
 
         // Act
         let range = repo.revwalk("1.0.0..")?;
@@ -545,9 +563,9 @@ mod test {
         // Arrange
         let repo = Repository::open(COCOGITTO_REPOSITORY)?;
         let v2_1_1 = Oid::from_str("9dcf728d2eef6b5986633dd52ecbe9e416234898")?;
-        let _v2_1_1 = OidOf::Tag(Tag::from_str("2.1.1", Some(v2_1_1), None)?);
+        let _v2_1_1 = OidOf::Tag(Tag::from_str("2.1.1", Some(v2_1_1))?);
         let v3_0_0 = Oid::from_str("c6508e243e2816e2d2f58828ee0c6721502958dd")?;
-        let v3_0_0 = OidOf::Tag(Tag::from_str("3.0.0", Some(v3_0_0), None)?);
+        let v3_0_0 = OidOf::Tag(Tag::from_str("3.0.0", Some(v3_0_0))?);
 
         // Act
         let range = repo.revwalk("2.1.1..3.0.0")?;
