@@ -68,7 +68,6 @@ impl VersionSpan {
             prefix: SETTINGS.tag_prefix.clone(),
             version,
             oid: None,
-            target: None,
         });
 
         // According to the pest grammar, a `version` or `latest_version` token is expected first
@@ -257,11 +256,8 @@ mod test {
     #[test]
     fn replace_version_cargo() -> Result<()> {
         let mut hook = Hook::from_str("cargo bump {{version}}")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("cargo bump 1.0.0");
         Ok(())
@@ -275,7 +271,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(None, Some(&HookVersion::new(tag)))
@@ -311,7 +306,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(None, Some(&HookVersion::new(tag)))
@@ -329,7 +323,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(Some(&HookVersion::new(tag)), None)
@@ -342,11 +335,8 @@ mod test {
     #[test]
     fn replace_maven_version() -> Result<()> {
         let mut hook = Hook::from_str("mvn versions:set -DnewVersion={{version}}")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("mvn versions:set -DnewVersion=1.0.0");
         Ok(())
@@ -355,11 +345,8 @@ mod test {
     #[test]
     fn replace_maven_version_with_expression() -> Result<()> {
         let mut hook = Hook::from_str("mvn versions:set -DnewVersion={{version+1minor-SNAPSHOT}}")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("mvn versions:set -DnewVersion=1.1.0-SNAPSHOT");
         Ok(())
@@ -374,7 +361,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(None, Some(&HookVersion::new(tag)))
@@ -411,7 +397,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(None, Some(&HookVersion::new(tag)))
@@ -425,11 +410,8 @@ mod test {
     #[test]
     fn leave_hook_untouched_when_no_version() -> Result<()> {
         let mut hook = Hook::from_str("echo \"Hello World\"")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("echo \"Hello World\"");
         Ok(())
@@ -438,11 +420,8 @@ mod test {
     #[test]
     fn replace_quoted_version() -> Result<()> {
         let mut hook = Hook::from_str("echo \"{{version}}\"")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("echo \"1.0.0\"");
         Ok(())
@@ -452,11 +431,8 @@ mod test {
     fn replace_version_with_nested_simple_quoted_arg() -> Result<()> {
         let mut hook =
             Hook::from_str("cog commit chore 'bump snapshot to {{version+1minor-pre}}'")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str()).is_equal_to("cog commit chore 'bump snapshot to 1.1.0-pre'");
         Ok(())
@@ -466,11 +442,8 @@ mod test {
     fn replace_version_with_nested_double_quoted_arg() -> Result<()> {
         let mut hook =
             Hook::from_str("cog commit chore \"bump snapshot to {{version+1minor-pre}}\"")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str())
             .is_equal_to("cog commit chore \"bump snapshot to 1.1.0-pre\"");
@@ -481,8 +454,8 @@ mod test {
     fn replace_version_with_multiple_placeholders() -> Result<()> {
         let mut hook = Hook::from_str("echo \"the latest {{latest}}, the greatest {{version}}\"")?;
         hook.insert_versions(
-            Some(&HookVersion::new(Tag::from_str("0.5.9", None, None)?)),
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
+            Some(&HookVersion::new(Tag::from_str("0.5.9", None)?)),
+            Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)),
         )
         .unwrap();
 
@@ -496,8 +469,8 @@ mod test {
             "echo \"the latest {{latest+3major+1minor}}, the greatest {{version+2patch}}\"",
         )?;
         hook.insert_versions(
-            Some(&HookVersion::new(Tag::from_str("0.5.9", None, None)?)),
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
+            Some(&HookVersion::new(Tag::from_str("0.5.9", None)?)),
+            Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)),
         )
         .unwrap();
 
@@ -509,11 +482,8 @@ mod test {
     fn replace_version_with_pre_and_build_metadata() -> Result<()> {
         let mut hook =
             Hook::from_str("echo \"the latest {{version+1major-pre.alpha-bravo+build.42}}\"")?;
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         assert_that!(hook.0.as_str())
             .is_equal_to("echo \"the latest 2.0.0-pre.alpha-bravo+build.42\"");
@@ -572,7 +542,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(None, Some(&HookVersion::new(tag)))
@@ -585,16 +554,14 @@ mod test {
     }
 
     #[sealed_test]
+    #[cfg(target_os = "linux")]
     fn parenthesis_in_hook_works() -> Result<()> {
         git_init_no_gpg()?;
 
         let mut hook = Hook::from_str("git commit --allow-empty -m 'chore(snapshot): bump snapshot to {{version+1patch-SNAPSHOT}}'")?;
 
-        hook.insert_versions(
-            None,
-            Some(&HookVersion::new(Tag::from_str("1.0.0", None, None)?)),
-        )
-        .unwrap();
+        hook.insert_versions(None, Some(&HookVersion::new(Tag::from_str("1.0.0", None)?)))
+            .unwrap();
 
         let outcome = hook.run(None);
 
@@ -630,7 +597,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         let tag = Tag {
@@ -638,7 +604,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 1, 0),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(
@@ -680,7 +645,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 0, 0),
             oid: None,
-            target: None,
         };
 
         let tag = Tag {
@@ -688,7 +652,6 @@ mod test {
             prefix: Some("v".to_string()),
             version: Version::new(1, 2, 3),
             oid: None,
-            target: None,
         };
 
         hook.insert_versions(
