@@ -1005,3 +1005,198 @@ fn changelog_on_first_commit_with_tag_on_first_commit() -> Result<()> {
 
     Ok(())
 }
+
+#[sealed_test]
+fn bump_from_latest_pre_release() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_commit("chore: init")?;
+    git_commit("feat: feature 1")?;
+    git_tag("1.0.0-alpha.0")?;
+    git_commit("feat: feature 2")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.0")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn bump_prerelease_from_latest_pre_release() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_commit("chore: init")?;
+    git_commit("feat: feature 1")?;
+    git_tag("1.0.0-alpha.0")?;
+    git_commit("feat: feature 2")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--pre")
+        .arg("beta.0")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.0-beta.0")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn bump_from_latest_pre_release_monorepo() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_add("packages.pkg.path = \"pkg\"", "cog.toml")?;
+    git_commit("chore: init")?;
+    git_commit("feat: feature 1")?;
+    git_tag("1.0.0-alpha.0")?;
+    git_tag("pkg-1.0.0-alpha.0")?;
+    std::fs::create_dir("pkg")?;
+    git_add("fn main() {}", "pkg/main.rs")?;
+    git_commit("feat: feature 2")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.0")?;
+    assert_tag_exists("pkg-1.0.0")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn bump_prerelease_from_latest_pre_release_monorepo() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_add("packages.pkg.path = \"pkg\"", "cog.toml")?;
+    git_commit("chore: init")?;
+    git_commit("feat: feature 1")?;
+    git_tag("1.0.0-alpha.0")?;
+    git_tag("pkg-1.0.0-alpha.0")?;
+    std::fs::create_dir("pkg")?;
+    git_add("fn main() {}", "pkg/main.rs")?;
+    git_commit("feat: feature 2")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--pre")
+        .arg("beta.0")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.0-beta.0")?;
+    assert_tag_exists("pkg-1.0.0-beta.0")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn bump_prerelease_ignore_packages() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_add(
+        indoc! {
+            r#"
+            [packages.a]
+            path = "a"
+
+            [packages.b]
+            path = "b"
+            "#
+        },
+        "cog.toml",
+    )?;
+    git_commit("chore: init")?;
+    git_tag("1.0.0")?;
+    git_tag("a-1.0.0")?;
+    git_tag("b-1.0.0")?;
+    git_add(".", "global")?;
+    git_add(".", "a/file")?;
+    git_commit("feat: do stuff")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--pre")
+        .arg("rc.1")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.1.0-rc.1")?;
+    assert_tag_exists("a-1.1.0-rc.1")?;
+    assert_tag_does_not_exist("b-1.0.0-rc.1")
+}
+
+#[sealed_test]
+fn major_bump_with_packages() -> Result<()> {
+    // Arrange
+    git_init()?;
+    git_add(
+        indoc! {
+            r#"
+            [packages.a]
+            path = "a"
+
+            [packages.b]
+            path = "b"
+            "#
+        },
+        "cog.toml",
+    )?;
+    git_commit("chore: init")?;
+    git_tag("0.1.0")?;
+    git_tag("a-0.1.0")?;
+    git_tag("b-0.1.0")?;
+
+    git_add(".", "a/feat")?;
+    git_add(".", "b/feat")?;
+    git_add(".", "feat")?;
+    git_commit("feat: release 1.0")?;
+
+    // Act
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--major")
+        .arg("--include-packages")
+        .assert()
+        .success();
+
+    // Assert
+    assert_tag_exists("1.0.0")?;
+    assert_tag_exists("a-1.0.0")?;
+    assert_tag_exists("b-1.0.0")?;
+
+    Ok(())
+}
+
+#[sealed_test]
+fn auto_bump_conflicts_with_include_packages() -> Result<()> {
+    Command::cargo_bin("cog")?
+        .arg("bump")
+        .arg("--auto")
+        .arg("--include-packages")
+        .assert()
+        .failure();
+
+    Ok(())
+}
