@@ -43,9 +43,9 @@ fn get_changelog_range() -> Result<()> {
         changelog.as_ref(),
         "## 0.32.3 - {today}
         #### Bug Fixes
-        - fix openssl missing in CD - (1c0d2e9) - oknozor
+        - fix openssl missing in CD - (1c0d2e9) - *oknozor*
         #### Documentation
-        - tag, conventional commit and license badges to readme - (da6f63d) - oknozor
+        - tag, conventional commit and license badges to readme - (da6f63d) - *oknozor*
 
         - - -
 
@@ -53,20 +53,20 @@ fn get_changelog_range() -> Result<()> {
         #### Bug Fixes
         - (**cd**) bump setup-rust-action to v1.3.3 - (5350b11) - *oknozor*
         #### Documentation
-        - add corrections to README - (9a33516) - oknozor
+        - add corrections to README - (9a33516) - *oknozor*
 
         - - -
 
         ## 0.32.1 - {today}
         #### Features
-        - move check edit to dedicated subcommand and fix rebase - (fc74207) - oknozor
-        - remove config commit on init existing repo - (1028d0b) - oknozor
+        - move check edit to dedicated subcommand and fix rebase - (fc74207) - *oknozor*
+        - remove config commit on init existing repo - (1028d0b) - *oknozor*
         #### Bug Fixes
         - (**cd**) fix ci cross build command bin args - (7f04a98) - *oknozor*
         #### Documentation
-        - rewritte readme completely - (b223f7b) - oknozor
+        - rewritte readme completely - (b223f7b) - *oknozor*
         #### Refactoring
-        - change config name to cog.toml - (d4aa61b) - oknozor
+        - change config name to cog.toml - (d4aa61b) - *oknozor*
 
 
         ",
@@ -998,30 +998,165 @@ fn changelog_monorepo_multi_versions() -> Result<()> {
     let sha_5 = cog_bump_auto()?;
 
     // Act
-    Command::cargo_bin("cog")?
+    let result = Command::cargo_bin("cog")?
         .arg("changelog")
+        // ignore package bumps until they are fixed
+        .arg("-t")
+        .arg("default")
         // Assert
         .assert()
-        .success()
-        .stdout(formatdoc!(
+        .success();
+
+    let changelog = result.get_output();
+    let changelog = &changelog.stdout;
+    let changelog = String::from_utf8_lossy(changelog.as_slice());
+
+    assert_eq!(
+        changelog,
+        format!(
             "## v0.1.1 - {today}
-            #### Bug Fixes
-            - combat nasty bug - ({sha_4}) - Tom
-            #### Miscellaneous Chores
-            - (**version**) v0.1.1 - ({sha_5}) - Tom
+#### Bug Fixes
+- combat nasty bug - ({sha_4}) - Tom
+#### Miscellaneous Chores
+- (**version**) v0.1.1 - ({sha_5}) - Tom
 
-            - - -
+- - -
 
-            ## v0.1.0 - {today}
-            #### Features
-            - add implementation - ({sha_2}) - Tom
-            #### Miscellaneous Chores
-            - (**version**) v0.1.0 - ({sha_3}) - Tom
-            - init - ({sha_1}) - Tom
+## v0.1.0 - {today}
+#### Features
+- add implementation - ({sha_2}) - Tom
+#### Miscellaneous Chores
+- (**version**) v0.1.0 - ({sha_3}) - Tom
+- init - ({sha_1}) - Tom
 
 
-            "
-        ));
+",
+            today = today,
+            sha_1 = sha_1,
+            sha_2 = sha_2,
+            sha_3 = sha_3,
+            sha_4 = sha_4,
+            sha_5 = sha_5,
+        )
+    );
+
+    Ok(())
+}
+
+#[sealed_test]
+fn unified_changelog() -> Result<()> {
+    // Arrange
+    git_init()?;
+    let today = Utc::now().date_naive();
+    let cog = indoc!(
+        r#"
+        [packages]
+        a = { path = "a" }
+        b = { path = "b" }
+        "#
+    );
+    git_add(cog, "cog.toml")?;
+    let sha_1 = git_commit_short("chore: init")?;
+    git_add(".", "a/feat")?;
+    let sha_2 = git_commit_short("feat(a): implement a")?;
+    git_add(".", "b/feat")?;
+    let sha_3 = git_commit_short("feat(b): implement b")?;
+    git_add(".", "a/fix")?;
+    git_add(".", "b/fix")?;
+    let sha_4 = git_commit_short("fix: everything")?;
+    git_tag("1.0.0")?;
+    git_tag("a-1.0.0")?;
+    git_tag("b-1.0.0")?;
+
+    // Act
+    let result = Command::cargo_bin("cog")?
+        .arg("changelog")
+        .arg("--unified")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = String::from_utf8_lossy(&result.get_output().stdout);
+
+    assert_eq!(
+        changelog,
+        formatdoc! {
+            r#"
+            ## 1.0.0 - {today}
+            ### Package updates
+            - a bumped to a-1.0.0
+            - b bumped to b-1.0.0
+            ### All changes
+            #### Features
+            - (**a**) implement a - ({sha_2}) - Tom
+            - (**b**) implement b - ({sha_3}) - Tom
+            #### Bug Fixes
+            - everything - ({sha_4}) - Tom
+            #### Miscellaneous Chores
+            - init - ({sha_1}) - Tom
+
+
+            "#,
+            today = today,
+            sha_1 = sha_1,
+            sha_2 = sha_2,
+            sha_3 = sha_3,
+            sha_4 = sha_4,
+        }
+    );
+
+    Ok(())
+}
+
+#[sealed_test]
+fn monorepo_changelog_default_template() -> Result<()> {
+    // Arrange
+    git_init()?;
+    let today = Utc::now().date_naive();
+    let cog = indoc!(
+        r#"
+        [packages]
+        pkg = { path = "pkg" }
+        "#
+    );
+    git_add(cog, "cog.toml")?;
+    let sha_1 = git_commit_short("chore: init")?;
+    git_add(".", "pkg/feat")?;
+    git_commit("feat(pkg): implement pkg")?;
+    git_add(".", "global/fix")?;
+    git_add(".", "pkg/fix")?;
+    let sha_2 = git_commit_short("fix: everything")?;
+    git_tag("0.1.0")?;
+    git_tag("pkg-0.1.0")?;
+
+    // Act
+    let result = Command::cargo_bin("cog")?
+        .arg("changelog")
+        // Assert
+        .assert()
+        .success();
+
+    let changelog = String::from_utf8_lossy(&result.get_output().stdout);
+
+    assert_eq!(
+        changelog,
+        formatdoc! {
+            r#"
+            ## 0.1.0 - {today}
+            ### Package updates
+            - pkg bumped to pkg-0.1.0
+            ### Global changes
+            #### Bug Fixes
+            - everything - ({sha_2}) - Tom
+            #### Miscellaneous Chores
+            - init - ({sha_1}) - Tom
+
+
+            "#,
+            today = today,
+            sha_1 = sha_1,
+        }
+    );
 
     Ok(())
 }
